# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import ir_qweb_fields
from . import ir_http
from . import ir_model
from . import ir_ui_menu
from . import ir_ui_view
from . import models
from . import base_document_layout
from . import res_config_settings
from . import res_partner
from . import res_users
